package fr.lri.keller.td5;

import android.content.Context;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.webkit.JavascriptInterface;
import android.webkit.WebSettings;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.Toast;

import java.util.HashMap;
import java.util.LinkedList;
import java.util.Map;

public class TD5Activity extends AppCompatActivity {

    private final String URL = "https://www.lri.fr/~keller/Enseignement/Orsay/LP-PRISM-AF/TD5.html";

    private WebView webview;
    private EditText editTextUrl;

    private void chargeUrl(final String url) {
        // Chargement de la page demandée
        // Utiliser directement [webview.loadUrl(url);] fonctionnait avec des versions plus
        // anciennes d'Android, mais n'est plus autorisé sur les APIs récentes : Android impose
        // maintenant que les opérations sur les vues web se fassent uniquement dans le thread
        // principal (ce qui est cohérent avec la politique d'Android), or l'utilisation de code
        // Java depuis JavaScript se fait dans un autre thread (là encore, pour éviter de bloquer
        // l'interface). Pour communiquer avec le thread principal lorsqu'on est dans un autre
        // thread non géré par la classe AsyncTask, on peut utiliser la méthode [post] de la classe
        // [View].
        webview.post(new Runnable() {
            public void run() {
                webview.loadUrl(url);
            }
        });
    }

    private void chargeEditTextUrl() {
        // Récupération de l'url entrée par l'utilisateur
        String url = editTextUrl.getText().toString();
        // Chargement de la page demandée
        chargeUrl(url);
        // Nettoyage de la barre d'url
        editTextUrl.setText("");
    }

    public class WebAppInterface {
        Context mContext;

        // Constructeur, récupérant le contexte de l'activité
        WebAppInterface(Context c) {
            mContext = c;
        }

        // Affiche un petit message
        @JavascriptInterface
        public void alert(String toast) {
            Toast.makeText(mContext, toast, Toast.LENGTH_SHORT).show();
        }

        // Charge l'url de la zone de texte
        @JavascriptInterface
        public void loadUserUrl() {
            chargeEditTextUrl();
        }
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_td5);
        // Récupération des vues
        webview = (WebView) findViewById(R.id.webview);
        editTextUrl = (EditText) findViewById(R.id.editTextUrl);
    }

    @Override
    protected void onStart() {
        super.onStart();
        // Permet d'avoir quelque chose qui se rapproche plus d'un navigateur, et donc d'ouvrir des
        // liens, par exemple
        webview.setWebViewClient(new WebViewClient());
        // Activation de JavaScript (qui est désactivé par défaut)
        WebSettings webSettings = webview.getSettings();
        webSettings.setJavaScriptEnabled(true);
        // Lien entre la classe WebAppInterface et le code JavaScript qui tourne dans l'application web
        webview.addJavascriptInterface(new WebAppInterface(this), "Android");
        // Chargement de la page web voulue
        chargeUrl(URL);
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_td5, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    public void precedent(View view) {
        webview.goBack();
    }

    public void suivant(View view) {
        webview.goForward();
    }

    public void rafraichir(View view) {
        webview.reload();
    }

    public void charger(View view) {
        chargeEditTextUrl();
    }
}
